#!/usr/bin/perl

use strict;
use warnings;

use Getopt::Long;
use Term::ANSIColor;

###############################################################################
#
# 	pdf4mergeunix has been written by Didier F.B Casse <didier@microtronyx.com>
#	Modified by Michael Stepanov <stepanov_michael@gmail.com> at 08/08/2005
#
###############################################################################
#
#  	This is pdfmerge4unix version 1.02.
# 	pdfmerge4unix is a command line utility program that merges pdf files in 
#	unix-based platforms.
#
#   Copyright (C) 2003 Didier F.B Casse
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
# 	Author: Didier F.B Casse, Singapore Synchrotron Light Source (SSLS).  
# 	Email: didier@microtronyx.com 
# 	URL : http://pdfmerge4unix.sourceforge.net
#
####################################################################################

my($opt_help, $opt_h);
my $debug = 0;
my $merged_tmp = '/tmp/merged.ps';
my $mergedfile = "/tmp/pdfmerge.pdf";

GetOptions('help', 'h', debug => \$debug, "output=s" => \$mergedfile);

my $usage = <<"END_OF_USAGE";
This is pdfmerge4unix version 1.03. pdfmerge4unix is a command line utility program that merges pdf files in unix-based platforms

Syntax:  pdfmerge [<options>] [--output=output.pdf] file1.pdf file2.pdf... fileN.pdf

Options:    --output      defines output PDF file (/tmp/pdfmerge.pdf by default)
            --debug       displays some useful debug information      
            --help        displays this brief help; same as -h
			
Author:    Didier F.B Casse <didier\@microtronyx.com>
Updated:   Michael Stepanov <stepanov.michael\@gmail.com>	
URL:       http://www.microtronyx.com/pdfmerge4unix
END_OF_USAGE

die $usage if ($opt_help or $opt_h or (scalar(@ARGV)==0));

my $incantation = << "END_OF_INCANTATION";
%!PS
/_begin_job_
{
        /tweak_save save def
        /tweak_dc countdictstack def
        /tweak_oc count 1 sub def
        userdict begin
}bind def

/_end_job_
{
        count tweak_oc sub{pop}repeat
        countdictstack tweak_dc sub{end}repeat
        tweak_save restore
}bind def

END_OF_INCANTATION

# get it started

# $mergedfile gets the output file!
#$mergedfile = pop(@ARGV);

#TWX: I don't need this check!
#if (-e $mergedfile){print color("red"), "outfile.pdf should not exists, it's the name of your output file!\n", color("reset"); exit 0;}


# Dealing with merged.ps 
open FILE, ">$merged_tmp" || die "Can't open $merged_tmp: $!!";
print FILE $incantation;

for (@ARGV){
	debug($_);

	print FILE "\n_begin_job_\n"; 
	print FILE "($_)run\n";
	print FILE "_end_job_\n";
	
	debug("($_)run");
}
	
close(FILE);

my $ret = `ps2pdf $merged_tmp $mergedfile`;

warn "[ERROR] $ret" if $ret;

#cleanup
unlink("$merged_tmp");

sub debug {
	my $msg = shift;	
	return unless $debug;
	my $time = localtime;
	print "[$time] [DEBUG] $msg \n";
}

=pod

=head2 Changelog

I've made following modifications in the pdfmerge4unix:

1) Added possibility to specify absolute path to the merged PDF files
2) Added possibility to display some debug information
3) 

=cut
